#!/usr/bin/env python
# coding=utf-8

from setuptools import setup
setup(
    name='frankstest',
    version=1,
    description=(
        '项目的简单描述'
    ),
    long_description='项目的详细描述',
    author='frank',
    author_email='luoziluojun@126.com',
    maintainer='frank',
    maintainer_email='luoziluojun@126.com',
    license='BSD License',
    # packages=find_packages(),
    platforms=["all"],
    url='http://ff2.pw',
    classifiers=[
        'Development Status :: 4 - Beta',
        'Operating System :: OS Independent',
        'Intended Audience :: Developers',
        'License :: OSI Approved :: BSD License',
        'Programming Language :: Python',
        'Programming Language :: Python :: Implementation',
        'Programming Language :: Python :: 2',
        'Programming Language :: Python :: 2.7',
        'Programming Language :: Python :: 3',
        'Programming Language :: Python :: 3.4',
        'Programming Language :: Python :: 3.5',
        'Programming Language :: Python :: 3.6',
        'Topic :: Software Development :: Libraries'
    ],
)